# SliceMap API

::: slicemap.SliceMap
    options:
        show_source: false
        heading_level: 2
        show_root_heading: true
        members_order: source
        show_object_full_path: false
        docstring_section_style: table
        show_signature_annotations: true
        separate_signature: false
        annotations_path: brief
        merge_init_into_class: true
        show_root_full_path: true
